<?php

namespace App\Http\Controllers;

use App\Models\Contact;
use App\Models\Setting;
use App\Models\Slider;
use App\Models\Bank;
use App\Models\Month;
use App\Models\MonthDescription;
use App\Models\MonthBill;
use App\User;
use App\Models\Building;
use App\Models\Flat;
use App\Models\CityDescription;
use App\Models\Hiring;
use App\Models\District;
use App\Models\City;
use App\Models\BuildingStatus;
use App\Models\BuildingType;
use App\Models\DistrictDescription;
use App\Models\BuildingTypeDescription;
use App\Models\BuildingStatusDescription;
use Illuminate\Http\Request;
use Auth;
use Session;
use Illuminate\Support\Facades\Artisan;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $setting=Setting::first();
        $sliders=Slider::all();
        $count_buildings = Building::where(['status' => 'active', 'type' => 'owner'])->count();
        $buildings_id = Building::where(['status' => 'active', 'type' => 'owner'])->pluck('id');
        $first_buildings = Building::where(['status' => 'active', 'type' => 'owner'])->orderBy('created_at','desc')->take($count_buildings/2)->get();
        $latest_buildings = Building::where(['status' => 'active', 'type' => 'owner'])->orderBy('created_at','asc')->take($count_buildings/2)->get();
        $cities_array = [];
        $cities=City::all();
        foreach ( $cities as $city) {
            $city_name=CityDescription::where(['language_id'=>1,'city_id'=>$city->id])->value('name');
            $cities_array[$city->id] = $city_name;
        }
        $districts_array = [];
        $districts=District::all();
        foreach ( $districts as $district) {
            $district_name=DistrictDescription::where(['language_id'=>1,'district_id'=>$district->id])->value('name');
            $districts_array[$district->id] = $district_name;
        }
        $building_statuses_array = [];
        $building_statuses=BuildingStatus::all();
        foreach ( $building_statuses as $building) {
            $building_status_name=BuildingStatusDescription::where(['language_id'=>1,'building_status_id'=>$building->id])->value('name');
            $building_statuses_array[$building->id] = $building_status_name;
        }
        $building_types_array = [];
        $building_types=BuildingType::all();
        foreach ( $building_types as $building) {
            $building_type_name=BuildingTypeDescription::where(['language_id'=>1,'building_type_id'=>$building->id])->value('name');
            $building_types_array[$building->id] = $building_type_name;
        }
        view()->share(array(
            'setting'=>$setting,
            'sliders'=>$sliders,
            'first_buildings'=>$first_buildings,
            'latest_buildings'=>$latest_buildings,
            'count_buildings'=>$count_buildings,
            'buildings_id'=>$buildings_id,
            'cities'        => $cities_array,
            'districts'        => $districts_array,
            'building_statuses'        => $building_statuses_array,
            'building_types'        => $building_types_array,
        ));
    }
    public static function lang(){
        if (session()->has('lang')) {
            if (session()->get('lang') == 'ar') {
                App::setlocale('ar');
                $lang='ar';
            }else{
                App::setlocale('en');
                $lang='en';
            }
        }else{
            $lang='ar';
            App::setlocale('ar');
        }

        return $lang;
    }
    public function index()
    {
        return view('web.index');
    }
    public function about()
    {
        return view('web.about');
    }
    public function bank_account()
    {
        $banks = Bank::all();
        $user=User::find(Auth::user()->id);
        $building=Building::find($user->building_id);
        $months=Month::where('building_id',$building->id)->orderBy('created_at','desc')->get();
        return view('web.bank-account',compact('banks','months'));
    }
    public function union()
    {
        $user=User::find(Auth::user()->id);
        $building = Building::find($user->building_id);
        $month=Month::where('building_id',$building->id)->orderBy('created_at','desc')->first();
        $users=User::where('building_id',$user->building_id)->get();
        $month_name = MonthDescription::where(['month_id' => $month->id, 'language_id' => 1])->value('name');
        $note = MonthDescription::where(['month_id' => $month->id, 'language_id' => 1])->value('note');
        return view('web.owners',compact('users','month','month_name','note'));
    }
    public function my_buildings()
    {
        $building_hiring_ids=Hiring::where('building_id','!=',null)->pluck('building_id');
        $hiring_buildings = Building::where(['client_id'=>Auth::guard('client')->user()->id,'have_flats'=>'0','type'=>'owner'])->whereIn('id',$building_hiring_ids)->get();
        $not_hiring_buildings = Building::where(['client_id'=>Auth::guard('client')->user()->id,'have_flats'=>'0','type'=>'owner'])->whereNotIn('id',$building_hiring_ids)->get();
        $salary=0;
        foreach ($hiring_buildings as $building) {
            $hiring=Hiring::where('building_id',$building->id)->first();
            if($hiring){
                $salary+=$building->rent;
            }
        }
        $flat_hiring_ids=Hiring::where('flat_id','!=',null)->pluck('flat_id');
        $building_ids = Building::where(['status' => 'active', 'type' => 'owner','client_id'=>Auth::guard('client')->user()->id,'have_flats'=>'1'])->pluck('id');
        $hiring_flats = Flat::whereIn('id',$flat_hiring_ids)->get();
        $not_hiring_flats = Flat::whereIn('building_id',$building_ids)->whereNotIn('id',$flat_hiring_ids)->get();
        foreach ($hiring_flats as $flat) {
            $hiring=Hiring::where('flat_id',$flat->id)->first();
            if($hiring){
                $salary+=$flat->rent;
            }
        }
        return view('web.my_buildings',compact('hiring_buildings','hiring_flats','not_hiring_buildings','not_hiring_flats','salary'));
    }
    public function contact(Request $request)
    {
        $contact = new Contact();
        $contact->name = $request->name;
        $contact->mobile = $request->mobile;
        $contact->content = $request->input('content');
        if($request->type=='owner'){
            $contact->client_id = $request->user_id;
        }elseif($request->type=='union'){
            $contact->user_id = $request->user_id;
        }elseif($request->type=='user' && $request->user_id!=""){
            $contact->user_id = $request->user_id;
        }
        $contact->save();
        return redirect('/')->with('created', 'تمت الارسال بنجاح');
    }
    public function bill(Request $request)
    {
        if(!$request->file('bill')){
            return 'a7a';
        }
        $file= $request->file('bill');
        $destinationPath = public_path() .'/images/bill/';
        $extension =  $file->clientExtension();
        $filename=str_random(10).'.'.$extension;
        $file->move($destinationPath, $filename);

        $month_bill=new MonthBill();
        $month_bill->image=$filename;
        $month_bill->month_id=$request->month_id;
        $month_bill->user_id=Auth::user()->id;
        $month_bill->confirm='0';
        $month_bill->save();
        return redirect('/')->with('created', 'تمت الارسال بنجاح');
    }
    public function buildings()
    {
        $buildings = Building::where(['status' => 'active', 'type' => 'owner','have_flats'=>'0'])->get();
        $building_ids = Building::where(['status' => 'active', 'type' => 'owner'])->pluck('id');
        $flats = Flat::whereIn('building_id',$building_ids)->get();
        return view('web.buildings',compact('buildings','flats'));
    }
    public function search(Request $request)
    {
        $buildings = Building::where(['status' => 'active', 'type' => 'owner','have_flats'=>'0'])->get();
        if ($request->district_id && $request->building_type_id && $request->building_status_id) {
            $buildings = Building::where(['status' => 'active', 'type' => 'owner','have_flats'=>'0','district_id'=>$request->district_id,'building_status_id'=>$request->building_status_id,'building_type_id'=>$request->building_type_id])->get();
        } elseif ($request->building_status_id && $request->building_type_id) {
            $buildings = Building::where(['status' => 'active', 'type' => 'owner','have_flats'=>'0','building_status_id'=>$request->building_status_id,'building_type_id'=>$request->building_type_id])->get();
        } elseif ($request->building_type_id) {
            $buildings = Building::where(['status' => 'active', 'type' => 'owner','have_flats'=>'0','building_type_id'=>$request->building_type_id])->get();
        }elseif ($request->building_status_id) {
            $buildings = Building::where(['status' => 'active', 'type' => 'owner','have_flats'=>'0','building_status_id'=>$request->building_status_id])->get();
        }elseif ($request->district_id) {
            $buildings = Building::where(['status' => 'active', 'type' => 'owner','have_flats'=>'0','district_id'=>$request->district_id])->get();
        }
        $building_ids = Building::where(['status' => 'active', 'type' => 'owner'])->pluck('id');
        if ($request->district_id && $request->building_type_id && $request->building_status_id) {
            $building_ids = Building::where(['status' => 'active', 'type' => 'owner','district_id'=>$request->district_id,'building_status_id'=>$request->building_status_id,'building_type_id'=>$request->building_type_id])->pluck('id');
        } elseif ($request->building_status_id && $request->building_type_id) {
            $building_ids = Building::where(['status' => 'active', 'type' => 'owner','building_status_id'=>$request->building_status_id,'building_type_id'=>$request->building_type_id])->pluck('id');
        } elseif ($request->building_type_id) {
            $building_ids = Building::where(['status' => 'active', 'type' => 'owner','building_type_id'=>$request->building_type_id])->pluck('id');
        }elseif ($request->building_status_id) {
            $building_ids = Building::where(['status' => 'active', 'type' => 'owner','building_status_id'=>$request->building_status_id])->pluck('id');
        }elseif ($request->district_id) {
            $building_ids = Building::where(['status' => 'active', 'type' => 'owner','district_id'=>$request->district_id])->pluck('id');
        }
        $flats = Flat::whereIn('building_id',$building_ids)->get();
        return view('web.buildings',compact('buildings','flats'));
    }
    public function building($id,$type)
    {
        if($type=='flat'){
            $building = Flat::find($id);
        }else{
            $building = Building::find($id);
        }
        return view('web.building',compact('building','type'));
    }


}
